@@ -21,14 +21,18 @@ class Sms(webdriver.Remote):
 
     def send_sms(self, phone_number, message):
         """Emulate send SMS event on the connected emulator.
+
         Android only.
 
-        :Args:
-         - phone_number: The phone number of message sender
-         - message: The message to send
+        Args:
+            phone_number (str): The phone number of message sender
+            message (str): The message to send
 
-        :Usage:
+        Usage:
             self.driver.send_sms('555-123-4567', 'Hey lol')
+
+        Returns:
+            `WebDriver`
         """
         self.execute(Command.SEND_SMS, {'phoneNumber': phone_number, 'message': message})
         return self
